@@ -236,3 +236,27 @@ class UdpSession(object):
                 return
 
             cls.send_packet(PacketTypeEnum.TX_PARAM, None, datas)
+
+    @classmethod
+    def send_relaypack(cls, packbytes):
+        packet_type = PacketTypeEnum.RELAY_PACK
+        import whatap.net.udp_thread
+        try:
+            if sum( [ len(x) for x in cls.buffer_arr]) + PacketEnum.PACKET_BODY_REQUIRED_SIZE + 1 > PacketEnum.PACKET_BUFFER_SIZE:
+                cls.send(packet_type, None)
+
+            if not packbytes:
+                return
+
+            dout = DataOutputX()
+            
+            # header
+            dout.writeByte(packet_type)
+            dout.writeInt(PacketEnum.PACKET_VERSION)
+            dout.writeIntBytes(packbytes)
+
+            with cls.thread_lock:
+                cls.buffer_arr.append(dout.toByteArray())
+        except Exception as e:
+            print(e)
+            logging.debug(e, extra={'id': 'WA262'}, exc_info=True)
\ No newline at end of file
