@@ -109,7 +109,10 @@ DEFINITION = {
         ('loguru._handler','instrument_loguru'),
     ],
     'application_fastapi': [
+        ('fastapi.applications', 'instrument_applications'),
         ('fastapi.routing', 'instrument'),
         ('fastapi.dependencies.utils', 'instrument_util'),
-    ],
+
+    ]
+
 }
